/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.adaptive.media.document.library.internal.util;

import com.liferay.petra.function.UnsafeSupplier;
import com.liferay.petra.lang.CentralizedThreadLocal;

/**
 * @author Adolfo Pérez
 */
public class AMCleanUpOnUpdateAndCheckInThreadLocal {

	public static <T, E extends Throwable> T enable(
			UnsafeSupplier<T, E> unsafeSupplier)
		throws E {

		boolean enabled = isEnabled();

		try {
			_cleanUpOnUpdateAndCheckIn.set(true);

			return unsafeSupplier.get();
		}
		finally {
			_cleanUpOnUpdateAndCheckIn.set(enabled);
		}
	}

	public static boolean isEnabled() {
		return _cleanUpOnUpdateAndCheckIn.get();
	}

	private static final ThreadLocal<Boolean> _cleanUpOnUpdateAndCheckIn =
		new CentralizedThreadLocal<>(
			AMCleanUpOnUpdateAndCheckInThreadLocal.class +
				"._cleanUpOnUpdateAndCheckIn",
			() -> Boolean.FALSE);

}